diff --git a/lib/classes/JsonApi/Routes/Courseware/UserProgressesOfUnitsShow.php b/lib/classes/JsonApi/Routes/Courseware/UserProgressesOfUnitsShow.php
index 48e7c95e47083223bf4373b5b74607db890b30f8..1e1745e2cdeae56062203455bfb3a096b9c950b6 100644
--- a/lib/classes/JsonApi/Routes/Courseware/UserProgressesOfUnitsShow.php
+++ b/lib/classes/JsonApi/Routes/Courseware/UserProgressesOfUnitsShow.php
@@ -95,7 +95,7 @@ class UserProgressesOfUnitsShow extends NonJsonApiController
     }
 
     private function getSelfProgresses(
-        iterable &$allBlockIds,
+        array &$allBlockIds,
         string $elementId,
         array &$userProgresses,
         array &$courseMemberIds
@@ -188,4 +188,4 @@ class UserProgressesOfUnitsShow extends NonJsonApiController
 
         return $data;
     }
-}
\ No newline at end of file
+}
diff --git a/lib/models/Courseware/Instance.php b/lib/models/Courseware/Instance.php
index bee37016af28eb928758b6907b79ef02f90c9383..5cff95314bd02bd07808e816b7d234083179eed1 100644
--- a/lib/models/Courseware/Instance.php
+++ b/lib/models/Courseware/Instance.php
@@ -412,7 +412,7 @@ class Instance
         return StructuralElement::findUsersBookmarksByRange($user, $this->getRange());
     }
 
-    public function findAllStructuralElements(): iterable
+    public function findAllStructuralElements(): array
     {
         $sql = 'SELECT se.*
                 FROM cw_structural_elements se
@@ -428,7 +428,7 @@ class Instance
         return $data;
     }
 
-    public function findAllBlocks(): iterable
+    public function findAllBlocks(): array
     {
         $sql = 'SELECT b.*
                 FROM cw_structural_elements se
@@ -452,10 +452,10 @@ class Instance
      *
      * @param ?callable(array $row): mixed $formatter Provide your own callable if you need something else instead of
      *                                                full-blown instances of \Courseware\Block.
      * @return iterable all the (optionally formatted) blocks grouped by the IDs of the structural element containing
      *                  that block.
      */
-    public function findAllBlocksGroupedByStructuralElementId(callable $formatter = null): iterable
+    public function findAllBlocksGroupedByStructuralElementId(callable $formatter = null): array
     {
         if (!$formatter) {
             $formatter = function ($row) {
@@ -452,10 +452,10 @@ class Instance
      * @param ?callable(array $row): mixed $formatter Provide your own callable if you need something else instead of
      *                                                full-blown instances of \Courseware\Block.
-     * @return iterable all the (optionally formatted) blocks grouped by the IDs of the structural element containing
+     * @return array all the (optionally formatted) blocks grouped by the IDs of the structural element containing
      *                  that block.
      */